@@ -71,25 +71,17 @@ def get_image_download_script(caller):
         raise ValueError('caller should only be one of `iplot` or `plot`')
 
     return(
-             ('<script>'
-              'function downloadimage(format, height, width,'
-              ' filename) {{'
-              'var p = document.getElementById(\'{plot_id}\');'
-              'Plotly.downloadImage(p, {{format: format, height: height, '
-              'width: width, filename: filename}});'
-              '}};' +
-              check_start +
-              'if(confirm(\'Do you want to save this image as '
-              '{filename}.{format}?\\n\\n'
-              'For higher resolution images and more export options, '
-              'consider making requests to our image servers. Type: '
-              'help(py.image) for more details.'
-              '\')) {{'
-              'downloadimage(\'{format}\', {height}, {width}, '
-              '\'{filename}\');}}' +
-              check_end +
-              '</script>'
-              )
+        ('<script>'
+         'function downloadimage(format, height, width,'
+         ' filename) {{'
+         'var p = document.getElementById(\'{plot_id}\');'
+         'Plotly.downloadImage(p, {{format: format, height: height, '
+         'width: width, filename: filename}});}};' +
+         check_start +
+         '{{downloadimage(\'{format}\', {height}, {width}, '
+         '\'{filename}\');}}' +
+         check_end +
+         '</script>')
     )
 
 
@@ -160,10 +152,18 @@ def init_notebook_mode(connected=False):
     __PLOTLY_OFFLINE_INITIALIZED = True
 
 
-def _plot_html(figure_or_data, show_link, link_text, validate,
-               default_width, default_height, global_requirejs):
-
-    figure = tools.return_figure_from_figure_or_data(figure_or_data, validate)
+def _plot_html(figure_or_data, config, validate, default_width,
+               default_height, global_requirejs):
+    # force no validation if frames is in the call
+    # TODO - add validation for frames in call - #605
+    if 'frames' in figure_or_data:
+        figure = tools.return_figure_from_figure_or_data(
+            figure_or_data, False
+        )
+    else:
+        figure = tools.return_figure_from_figure_or_data(
+            figure_or_data, validate
+        )
 
     width = figure.get('layout', {}).get('width', default_width)
     height = figure.get('layout', {}).get('height', default_height)
@@ -185,30 +185,72 @@ def _plot_html(figure_or_data, show_link, link_text, validate,
     plotdivid = uuid.uuid4()
     jdata = json.dumps(figure.get('data', []), cls=utils.PlotlyJSONEncoder)
     jlayout = json.dumps(figure.get('layout', {}), cls=utils.PlotlyJSONEncoder)
+    if 'frames' in figure_or_data:
+        jframes = json.dumps(figure.get('frames', {}), cls=utils.PlotlyJSONEncoder)
 
-    config = {}
-    config['showLink'] = show_link
-    config['linkText'] = link_text
-    jconfig = json.dumps(config)
+    configkeys = (
+        'editable',
+        'autosizable',
+        'fillFrame',
+        'frameMargins',
+        'scrollZoom',
+        'doubleClick',
+        'showTips',
+        'showLink',
+        'sendData',
+        'linkText',
+        'showSources',
+        'displayModeBar',
+        'modeBarButtonsToRemove',
+        'modeBarButtonsToAdd',
+        'modeBarButtons',
+        'displaylogo',
+        'plotGlPixelRatio',
+        'setBackground',
+        'topojsonURL'
+    )
+
+    config_clean = dict((k, config[k]) for k in configkeys if k in config)
+    jconfig = json.dumps(config_clean)
 
     # TODO: The get_config 'source of truth' should
     # really be somewhere other than plotly.plotly
     plotly_platform_url = plotly.plotly.get_config().get('plotly_domain',
                                                          'https://plot.ly')
     if (plotly_platform_url != 'https://plot.ly' and
-            link_text == 'Export to plot.ly'):
+            config['linkText'] == 'Export to plot.ly'):
 
         link_domain = plotly_platform_url\
             .replace('https://', '')\
             .replace('http://', '')
-        link_text = link_text.replace('plot.ly', link_domain)
+        link_text = config['linkText'].replace('plot.ly', link_domain)
         config['linkText'] = link_text
+        jconfig = jconfig.replace('Export to plot.ly', link_text)
 
-    script = 'Plotly.newPlot("{id}", {data}, {layout}, {config})'.format(
-        id=plotdivid,
-        data=jdata,
-        layout=jlayout,
-        config=jconfig)
+    if 'frames' in figure_or_data:
+        script = '''
+        Plotly.plot(
+            '{id}',
+            {data},
+            {layout},
+            {config}
+        ).then(function () {add_frames}).then(function(){animate})
+        '''.format(
+            id=plotdivid,
+            data=jdata,
+            layout=jlayout,
+            config=jconfig,
+            add_frames="{" + "return Plotly.addFrames('{id}',{frames}".format(
+                id=plotdivid, frames=jframes
+            ) + ");}",
+            animate="{" + "Plotly.animate('{id}');".format(id=plotdivid) + "}"
+        )
+    else:
+        script = 'Plotly.newPlot("{id}", {data}, {layout}, {config})'.format(
+            id=plotdivid,
+            data=jdata,
+            layout=jlayout,
+            config=jconfig)
 
     optional_line1 = ('require(["plotly"], function(Plotly) {{ '
                       if global_requirejs else '')
@@ -232,6 +274,7 @@ def _plot_html(figure_or_data, show_link, link_text, validate,
 
     return plotly_html_div, plotdivid, width, height
 
+
 def iplot(figure_or_data, show_link=True, link_text='Export to plot.ly',
           validate=True, image=None, filename='plot_image', image_width=800,
           image_height=600):
@@ -260,7 +303,9 @@ def iplot(figure_or_data, show_link=True, link_text='Export to plot.ly',
     image (default=None |'png' |'jpeg' |'svg' |'webp') -- This parameter sets
         the format of the image to be downloaded, if we choose to download an
         image. This parameter has a default value of None indicating that no
-        image should be downloaded.
+        image should be downloaded. Please note: for higher resolution images
+        and more export options, consider making requests to our image servers.
+        Type: `help(py.image)` for more details.
     filename (default='plot') -- Sets the name of the file your image
         will be saved to. The extension should not be included.
     image_height (default=600) -- Specifies the height of the image in `px`.
@@ -288,9 +333,13 @@ def iplot(figure_or_data, show_link=True, link_text='Export to plot.ly',
     if not tools._ipython_imported:
         raise ImportError('`iplot` can only run inside an IPython Notebook.')
 
+    config = {}
+    config['showLink'] = show_link
+    config['linkText'] = link_text
+
     plot_html, plotdivid, width, height = _plot_html(
-        figure_or_data, show_link, link_text, validate,
-        '100%', 525, global_requirejs=True)
+        figure_or_data, config, validate, '100%', 525, True
+    )
 
     display(HTML(plot_html))
 
@@ -301,23 +350,20 @@ def iplot(figure_or_data, show_link=True, link_text='Export to plot.ly',
                              )
         # if image is given, and is a valid format, we will download the image
         script = get_image_download_script('iplot').format(format=image,
-                                                       width=image_width,
-                                                       height=image_height,
-                                                       filename=filename,
-                                                       plot_id=plotdivid)
+                                                           width=image_width,
+                                                           height=image_height,
+                                                           filename=filename,
+                                                           plot_id=plotdivid)
         # allow time for the plot to draw
         time.sleep(1)
         # inject code to download an image of the plot
         display(HTML(script))
 
 
-def plot(figure_or_data,
-         show_link=True, link_text='Export to plot.ly',
-         validate=True, output_type='file',
-         include_plotlyjs=True,
-         filename='temp-plot.html', auto_open=True,
-         image=None, image_filename='plot_image',
-         image_width=800, image_height=600):
+def plot(figure_or_data, show_link=True, link_text='Export to plot.ly',
+         validate=True, output_type='file', include_plotlyjs=True,
+         filename='temp-plot.html', auto_open=True, image=None,
+         image_filename='plot_image', image_width=800, image_height=600):
     """ Create a plotly graph locally as an HTML document or string.
 
     Example:
@@ -370,9 +416,11 @@ def plot(figure_or_data,
     image (default=None |'png' |'jpeg' |'svg' |'webp') -- This parameter sets
         the format of the image to be downloaded, if we choose to download an
         image. This parameter has a default value of None indicating that no
-        image should be downloaded.
-    image_filename (default='plot_image') -- Sets the name of the file your image
-        will be saved to. The extension should not be included.
+        image should be downloaded. Please note: for higher resolution images
+        and more export options, consider making requests to our image servers.
+        Type: `help(py.image)` for more details.
+    image_filename (default='plot_image') -- Sets the name of the file your
+        image will be saved to. The extension should not be included.
     image_height (default=600) -- Specifies the height of the image in `px`.
     image_width (default=800) -- Specifies the width of the image in `px`.
     """
@@ -386,8 +434,12 @@ def plot(figure_or_data,
             "Adding .html to the end of your file.")
         filename += '.html'
 
+    config = {}
+    config['showLink'] = show_link
+    config['linkText'] = link_text
+
     plot_html, plotdivid, width, height = _plot_html(
-        figure_or_data, show_link, link_text, validate,
+        figure_or_data, config, validate,
         '100%', '100%', global_requirejs=False)
 
     resize_script = ''
